summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/include')
-rw-r--r--src/include/novel_types.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/include/novel_types.h b/src/include/novel_types.h
index e2d2363..52fc0b0 100644
--- a/src/include/novel_types.h
+++ b/src/include/novel_types.h
@@ -86,7 +86,8 @@ enum ErrorResult{
ERROR_OUT_OF_RANGE, /* beyond the end of the sub phrase index */
ERROR_FILE_CORRUPTION, /* file is corrupted */
ERROR_INTEGER_OVERFLOW, /* integer is overflowed */
- ERROR_ALREADY_EXISTS /* the sub phrase already exists. */
+ ERROR_ALREADY_EXISTS, /* the sub phrase already exists. */
+ ERROR_NO_USER_TABLE /* the user table is not loaded. */
};
/* For N-gram */